CREATE TABLE PrimaryTable_Large ( 
ID INT IDENTITY PRIMARY KEY, 
SomeColumn CHAR(4) NULL, 
Filler CHAR(100) 
); 

CREATE TABLE SecondaryTable_Large ( 
ID INT IDENTITY PRIMARY KEY, 
LookupColumn CHAR(4) NULL, 
SomeArbDate DATETIME DEFAULT GETDATE() 
) 

CREATE TABLE PrimaryTable_Medium ( 
ID INT IDENTITY PRIMARY KEY, 
SomeColumn CHAR(4) NULL, 
Filler CHAR(100) 
); 

CREATE TABLE SecondaryTable_Medium ( 
ID INT IDENTITY PRIMARY KEY, 
LookupColumn CHAR(4) NULL, 
SomeArbDate DATETIME DEFAULT GETDATE() 
);

/*CREATE TABLE SecondaryTable_Medium2 ( 
ID INT IDENTITY PRIMARY KEY, 
LookupColumn CHAR(4) NULL, 
SomeArbDate DATETIME DEFAULT GETDATE() 
); */

CREATE TABLE PrimaryTable_Small ( 
ID INT IDENTITY PRIMARY KEY, 
SomeColumn CHAR(4) NULL, 
Filler CHAR(100) 
);

CREATE TABLE SecondaryTable_Small ( 
ID INT IDENTITY PRIMARY KEY, 
LookupColumn CHAR(4) NULL, 
SomeArbDate DATETIME DEFAULT GETDATE() 
);

-- large table 
INSERT INTO PrimaryTable_Large (SomeColumn) 
SELECT top 1000000 
char(65+FLOOR(RAND(a.column_id *5645 + b.object_id)*10)) + char(65+FLOOR(RAND(b.column_id *3784 + b.object_id)*12)) + 
char(65+FLOOR(RAND(b.column_id *6841 + a.object_id)*12)) + char(65+FLOOR(RAND(a.column_id *7544 + b.object_id)*8)) 
from msdb.sys.columns a cross join msdb.sys.columns b 

INSERT INTO SecondaryTable_Large (LookupColumn) 
SELECT DISTINCT SomeColumn 
FROM PrimaryTable_Large TABLESAMPLE (65 PERCENT) -- 11216 rows
GO

-- medium table
INSERT INTO PrimaryTable_Medium (SomeColumn) 
SELECT top 50000 
CHAR(65+FLOOR(RAND(a.column_id *5645 + b.object_id)*10)) + CHAR(65+FLOOR(RAND(b.column_id *3784 + b.object_id)*12)) + 
CHAR(65+FLOOR(RAND(b.column_id *6841 + a.object_id)*12)) + CHAR(65+FLOOR(RAND(a.column_id *7544 + b.object_id)*8)) 
from msdb.sys.columns a cross join msdb.sys.columns b 

INSERT INTO SecondaryTable_Medium (LookupColumn) 
SELECT DISTINCT SomeColumn 
FROM PrimaryTable_Medium TABLESAMPLE (45 PERCENT) -- 5157 rows

-- Alternate secondary (larger than primary)
INSERT INTO SecondaryTable_Medium2 (LookupColumn) 
SELECT top 75000 
CHAR(65+FLOOR(RAND(a.column_id *5645 + b.object_id)*10)) + CHAR(65+FLOOR(RAND(b.column_id *3784 + b.object_id)*12)) + 
CHAR(65+FLOOR(RAND(b.column_id *6841 + a.object_id)*12)) + CHAR(65+FLOOR(RAND(a.column_id *7544 + b.object_id)*8)) 
from msdb.sys.columns a cross join msdb.sys.columns b 
GO

-- small table
INSERT INTO PrimaryTable_Small (SomeColumn) 
SELECT top 2500 
CHAR(65+FLOOR(RAND(a.column_id *5645 + b.object_id)*10)) + CHAR(65+FLOOR(RAND(b.column_id *3784 + b.object_id)*12)) + 
CHAR(65+FLOOR(RAND(b.column_id *6841 + a.object_id)*12)) + CHAR(65+FLOOR(RAND(a.column_id *7544 + b.object_id)*8)) 
from msdb.sys.columns a cross join msdb.sys.columns b 

INSERT INTO SecondaryTable_Small (LookupColumn) 
SELECT DISTINCT SomeColumn 
FROM PrimaryTable_Small TABLESAMPLE (25 PERCENT) -- 154 rows
GO

-- Run first set of tests of IN, Exists and Inner Join 

CREATE NONCLUSTERED INDEX idx_PrimaryTableLarge_SomeColumn ON PrimaryTable_Large (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableLarge_LookupColumn ON SecondaryTable_Large (LookupColumn)
CREATE NONCLUSTERED INDEX idx_PrimaryTableMedium_SomeColumn ON PrimaryTable_Medium (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableMedium_LookupColumn ON SecondaryTable_Medium (LookupColumn)
CREATE NONCLUSTERED INDEX idx_PrimaryTableSmall_SomeColumn ON PrimaryTable_Small (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableSmall_LookupColumn ON SecondaryTable_Small (LookupColumn)
GO

--Run second set of tests of IN, Exists and Inner Join 

DROP INDEX idx_PrimaryTableLarge_SomeColumn ON PrimaryTable_Large
DROP INDEX idx_SecondaryTableLarge_LookupColumn ON SecondaryTable_Large
DROP INDEX idx_PrimaryTableMedium_SomeColumn ON PrimaryTable_Medium
DROP INDEX idx_SecondaryTableMedium_LookupColumn ON SecondaryTable_Medium
DROP INDEX idx_PrimaryTableSmall_SomeColumn ON PrimaryTable_Small
DROP INDEX idx_SecondaryTableSmall_LookupColumn ON SecondaryTable_Small
GO

-- Run first set of tests on NOT In, Not Exists and Left Outer Join

CREATE NONCLUSTERED INDEX idx_PrimaryTableLarge_SomeColumn ON PrimaryTable_Large (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableLarge_LookupColumn ON SecondaryTable_Large (LookupColumn)
CREATE NONCLUSTERED INDEX idx_PrimaryTableMedium_SomeColumn ON PrimaryTable_Medium (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableMedium_LookupColumn ON SecondaryTable_Medium (LookupColumn)
CREATE NONCLUSTERED INDEX idx_PrimaryTableSmall_SomeColumn ON PrimaryTable_Small (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableSmall_LookupColumn ON SecondaryTable_Small (LookupColumn)
GO

-- Run second set of tests on NOT In, Not Exists and Left Outer Join

DROP INDEX idx_PrimaryTableLarge_SomeColumn ON PrimaryTable_Large
DROP INDEX idx_SecondaryTableLarge_LookupColumn ON SecondaryTable_Large
DROP INDEX idx_PrimaryTableMedium_SomeColumn ON PrimaryTable_Medium
DROP INDEX idx_SecondaryTableMedium_LookupColumn ON SecondaryTable_Medium
DROP INDEX idx_PrimaryTableSmall_SomeColumn ON PrimaryTable_Small
DROP INDEX idx_SecondaryTableSmall_LookupColumn ON SecondaryTable_Small
GO

ALTER TABLE PrimaryTable_Large ALTER COLUMN SomeColumn CHAR(4) NOT NULL
ALTER TABLE SecondaryTable_Large ALTER COLUMN LookupColumn CHAR(4) NOT NULL
ALTER TABLE PrimaryTable_Medium ALTER COLUMN SomeColumn CHAR(4) NOT NULL
ALTER TABLE SecondaryTable_Medium ALTER COLUMN LookupColumn CHAR(4) NOT NULL
ALTER TABLE PrimaryTable_Small ALTER COLUMN SomeColumn CHAR(4) NOT NULL
ALTER TABLE SecondaryTable_Small ALTER COLUMN LookupColumn CHAR(4) NOT NULL

-- Run third set of tests on NOT In, Not Exists and Left Outer Join

CREATE NONCLUSTERED INDEX idx_PrimaryTableLarge_SomeColumn ON PrimaryTable_Large (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableLarge_LookupColumn ON SecondaryTable_Large (LookupColumn)
CREATE NONCLUSTERED INDEX idx_PrimaryTableMedium_SomeColumn ON PrimaryTable_Medium (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableMedium_LookupColumn ON SecondaryTable_Medium (LookupColumn)
CREATE NONCLUSTERED INDEX idx_PrimaryTableSmall_SomeColumn ON PrimaryTable_Small (SomeColumn)
CREATE NONCLUSTERED INDEX idx_SecondaryTableSmall_LookupColumn ON SecondaryTable_Small (LookupColumn)
GO

-- Run fourth set of tests on NOT In, Not Exists and Left Outer Join


-- cleanup

DROP TABLE dbo.PrimaryTable_Large
DROP TABLE dbo.SecondaryTable_Large
DROP TABLE dbo.PrimaryTable_Medium
DROP TABLE dbo.SecondaryTable_Medium
DROP TABLE dbo.PrimaryTable_Small
DROP TABLE dbo.SecondaryTable_Small